bounds property

Rect? bounds
final

Global screen bounds of the nearest descendant RenderBox (this element's own render object if it has one, otherwise the first one found walking down through its children), if it has been laid out.

Implementation

final Rect? bounds;