enabled property
Set to false to disable auditing without removing the widget (e.g. from a debug settings toggle). Has no effect in release builds, which are always disabled.
Implementation
final bool enabled;
Set to false to disable auditing without removing the widget (e.g. from a debug settings toggle). Has no effect in release builds, which are always disabled.
final bool enabled;