id property
The SemanticsNode.id this snapshot was captured from. Stable for the node's lifetime, useful for matching a node across successive walks.
Implementation
final int id;
The SemanticsNode.id this snapshot was captured from. Stable for the node's lifetime, useful for matching a node across successive walks.
final int id;