enabled property

bool enabled
final

Set to false to disable auditing without removing the widget (e.g. from a debug settings toggle). Has no effect in release builds, which are always disabled.

Implementation

final bool enabled;